@@ -20,7 +20,7 @@ Module for watching fedmsg messages and running scripts based on those messages
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
     USA
 """
-__version__='0.4'
+__version__='0.5'
 
 import errno
 import os
@@ -86,7 +86,7 @@ class FedWatch(object):
                     continue
 
                 procarg=[fpath]
-                procarg.extend(pargs)
+                procarg.extend([str(parg) for parg in pargs])
                 st = os.stat(fpath)
                 proc_owner = os.getuid()
                 mode = st.st_mode
